==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/outputs/CommonDataServiceForAppsEntityDatasetResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.outputs

import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * The Common Data Service for Apps entity dataset.
 * @property annotations List of tags that can be used for describing the Dataset.
 * @property description Dataset description.
 * @property entityName The logical name of the entity. Type: string (or Expression with resultType string).
 * @property folder The folder that this Dataset is in. If not specified, Dataset will appear at the root level.
 * @property linkedServiceName Linked service reference.
 * @property parameters Parameters for dataset.
 * @property schema Columns that define the physical type schema of the dataset. Type: array (or Expression with resultType array), itemType: DatasetSchemaDataElement.
 * @property structure Columns that define the structure of the dataset. Type: array (or Expression with resultType array), itemType: DatasetDataElement.
 * @property type Type of dataset.
 * Expected value is 'CommonDataServiceForAppsEntity'.
 */
public data class CommonDataServiceForAppsEntityDatasetResponse(
    public val annotations: List<Any>? = null,
    public val description: String? = null,
    public val entityName: Any? = null,
    public val folder: DatasetResponseFolder? = null,
    public val linkedServiceName: LinkedServiceReferenceResponse,
    public val parameters: Map<String, ParameterSpecificationResponse>? = null,
    public val schema: Any? = null,
    public val structure: Any? = null,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.datafactory.outputs.CommonDataServiceForAppsEntityDatasetResponse):
            CommonDataServiceForAppsEntityDatasetResponse =
            CommonDataServiceForAppsEntityDatasetResponse(
                annotations = javaType.annotations().map({ args0 -> args0 }),
                description = javaType.description().map({ args0 -> args0 }).orElse(null),
                entityName = javaType.entityName().map({ args0 -> args0 }).orElse(null),
                folder = javaType.folder().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.datafactory.kotlin.outputs.DatasetResponseFolder.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                linkedServiceName = javaType.linkedServiceName().let({ args0 ->
                    com.pulumi.azurenative.datafactory.kotlin.outputs.LinkedServiceReferenceResponse.Companion.toKotlin(args0)
                }),
                parameters = javaType.parameters().map({ args0 ->
                    args0.key.to(
                        args0.value.let({ args0 ->
                            com.pulumi.azurenative.datafactory.kotlin.outputs.ParameterSpecificationResponse.Companion.toKotlin(args0)
                        }),
                    )
                }).toMap(),
                schema = javaType.schema().map({ args0 -> args0 }).orElse(null),
                structure = javaType.structure().map({ args0 -> args0 }).orElse(null),
                type = javaType.type(),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/outputs/CommonDataServiceForAppsEntityDatasetResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.outputs

import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * The Common Data Service for Apps entity dataset.
 * @property annotations List of tags that can be used for describing the Dataset.
 * @property description Dataset description.
 * @property entityName The logical name of the entity. Type: string (or Expression with resultType string).
 * @property folder The folder that this Dataset is in. If not specified, Dataset will appear at the root level.
 * @property linkedServiceName Linked service reference.
 * @property parameters Parameters for dataset.
 * @property schema Columns that define the physical type schema of the dataset. Type: array (or Expression with resultType array), itemType: DatasetSchemaDataElement.
 * @property structure Columns that define the structure of the dataset. Type: array (or Expression with resultType array), itemType: DatasetDataElement.
 * @property type Type of dataset.
 * Expected value is 'CommonDataServiceForAppsEntity'.
 */
public data class CommonDataServiceForAppsEntityDatasetResponse(
    public val annotations: List<Any>? = null,
    public val description: String? = null,
    public val entityName: Any? = null,
    public val folder: DatasetResponseFolder? = null,
    public val linkedServiceName: LinkedServiceReferenceResponse,
    public val parameters: Map<String, ParameterSpecificationResponse>? = null,
    public val schema: Any? = null,
    public val structure: Any? = null,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.datafactory.outputs.CommonDataServiceForAppsEntityDatasetResponse): CommonDataServiceForAppsEntityDatasetResponse =
            CommonDataServiceForAppsEntityDatasetResponse(
                annotations = javaType.annotations().map({ args0 -> args0 }),
                description = javaType.description().map({ args0 -> args0 }).orElse(null),
                entityName = javaType.entityName().map({ args0 -> args0 }).orElse(null),
                folder = javaType.folder().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.datafactory.kotlin.outputs.DatasetResponseFolder.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                linkedServiceName = javaType.linkedServiceName().let({ args0 ->
                    com.pulumi.azurenative.datafactory.kotlin.outputs.LinkedServiceReferenceResponse.Companion.toKotlin(args0)
                }),
                parameters = javaType.parameters().map({ args0 ->
                    args0.key.to(
                        args0.value.let({ args0 ->
                            com.pulumi.azurenative.datafactory.kotlin.outputs.ParameterSpecificationResponse.Companion.toKotlin(args0)
                        }),
                    )
                }).toMap(),
                schema = javaType.schema().map({ args0 -> args0 }).orElse(null),
                structure = javaType.structure().map({ args0 -> args0 }).orElse(null),
                type = javaType.type(),
            )
    }
}
